@@ -1,10 +1,15 @@
 import sys
 
+import ipaddress
+
 # pylint: skip-file
 
 if sys.version_info[0] == 2:
-    import ipaddr as ipaddress  # pylint:disable=F0401
-    ipaddress.ip_address = ipaddress.IPAddress
+
+    def compat_ip_address(address):
+        if isinstance(address, bytes):
+            address = address.decode()
+        return ipaddress.ip_address(address)
 
     int_from_byte = ord
 
@@ -17,7 +22,9 @@ if sys.version_info[0] == 2:
 
     byte_from_int = chr
 else:
-    import ipaddress  # pylint:disable=F0401
+
+    def compat_ip_address(address):
+        return ipaddress.ip_address(address)
 
     int_from_byte = lambda x: x
 
